@@ -9,6 +9,8 @@ from pandas.api.types import (
     is_object_dtype,
 )
 
+from profiling.utils import vega_sanitize
+
 
 def partialdep(func, X, y, var):
     """Plot partial dependence"""
@@ -68,25 +70,28 @@ def partialdep_num(func, X, y, var):
         )
         df_ice = df_ice.append(df_ice_q, ignore_index=True, sort=False)
 
+    df_mean = df_ice.groupby(by=var, as_index=False).agg({"Predicted Value": "mean"})
+
     # Create plot
+    var_sanitized = vega_sanitize(var, datatype="Q")
+
     lines = (
         alt.Chart(df_ice)
         .mark_line(strokeOpacity=0.3, color="grey", strokeWidth=2)
         .encode(
-            x=var,
+            x=var_sanitized,
             y=alt.Y("Predicted Value:Q", scale=alt.Scale(zero=False)),
             detail="id",
         )
     )
-    df_mean = df_ice.groupby(by=var, as_index=False).agg({"Predicted Value": "mean"})
     mean = (
         alt.Chart(df_mean)
         .mark_line(strokeWidth=3, point=True)
         .encode(
-            x=var,
+            x=var_sanitized,
             y=alt.Y("Predicted Value:Q", scale=alt.Scale(zero=False)),
             tooltip=[
-                alt.Tooltip(f"{var}:Q", format=".2f"),
+                alt.Tooltip(var_sanitized, format=".2f"),
                 alt.Tooltip(f"Predicted Value:Q", format=".2f"),
             ],
         )
@@ -136,13 +141,15 @@ def partialdep_cat(func, X, y, var, n_categories=100, n_sample=50):
     df_plot_sample = df_plot.query(f"id < {n_sample}")
 
     # Create plot
+    var_sanitized = vega_sanitize(var, "N")
+
     lines = (
         alt.Chart(df_plot_sample)
         .mark_line(strokeOpacity=0.3, color="grey", strokeWidth=2)
         .encode(
             x=alt.X("Predicted Value", scale=alt.Scale(zero=False)),
             y=alt.Y(
-                var,
+                var_sanitized,
                 sort=df_plot[var].cat.categories.to_list(),
                 scale=alt.Scale(zero=False),
             ),
@@ -155,11 +162,11 @@ def partialdep_cat(func, X, y, var, n_categories=100, n_sample=50):
         .encode(
             x="Predicted Value",
             y=alt.Y(
-                var,
+                var_sanitized,
                 sort=df_plot[var].cat.categories.to_list(),
                 scale=alt.Scale(zero=False),
             ),
-            tooltip=[var, alt.Tooltip(f"Predicted Value:Q", format=".2f")],
+            tooltip=[var_sanitized, alt.Tooltip(f"Predicted Value:Q", format=".2f"),],
         )
         .interactive()
     )
