@@ -31,6 +31,24 @@ comb = np.vectorize(
 )
 
 
+def fast_object_mode(s):
+    """Calculate mode of Series through intermediate string representation instead of hash table
+
+    Parameters
+    ----------
+    s : pd.Series
+        Pandas Series
+
+    Returns
+    -------
+    Modal value
+    """
+    s_string = s.astype(str)
+    _, indices, counts = np.unique(s_string, return_index=True, return_counts=True)
+    index_max = indices[counts.argmax()]
+    return s[index_max]
+
+
 class Explainer(ABC):
     @abstractmethod
     def explain(self, X):
@@ -110,10 +128,13 @@ class ShapExplainer(Explainer):
     def _create_background_data(X):
         """Create single-row background dataset"""
         background = {}
-        for col in X.select_dtypes(include="number").columns:
-            background[col] = [X[col].median()]
-        for col in X.select_dtypes(exclude="number").columns:
-            background[col] = [X[col].mode(dropna=False).values[0]]
+        for col in X.columns:
+            if pd.api.types.is_numeric_dtype(X[col]):
+                background[col] = [X[col].median()]
+            elif pd.api.types.is_object_dtype(X[col]):
+                background[col] = [fast_object_mode(X[col])]
+            else:
+                background[col] = [X[col].mode(dropna=False).values[0]]
         X_background = pd.DataFrame(background, columns=X.columns).astype(X.dtypes)
         return X_background
 
