@@ -5,7 +5,14 @@ import numpy as np
 import pandas as pd
 import pytest
 
-from profiling.shap import ShapExplainer, comb, n_choose_k, reduce_func, update_columns
+from profiling.shap import (
+    ShapExplainer,
+    comb,
+    fast_object_mode,
+    n_choose_k,
+    reduce_func,
+    update_columns,
+)
 
 
 @pytest.mark.parametrize("n_cols", [1, 2, 3, 4])
@@ -100,11 +107,21 @@ def test_various_coltypes():
     def regression(X):
         return np.random.uniform(size=len(X))
 
-    with pytest.warns(UserWarning):  # undefined modes for some columns
-        shap_explainer = ShapExplainer(func=regression, X=X)
+    shap_explainer = ShapExplainer(func=regression, X=X)
     ref, shap = shap_explainer.explain(X)
 
 
+def test_fast_object_mode():
+    """Test string mode calculation"""
+    assert fast_object_mode(pd.Series([1, 2, 1])) == 1
+    assert fast_object_mode(pd.Series([1.0, 2.0, 3.0])) == 1.0
+    assert fast_object_mode(pd.Series([1.0, 1.0, None])) == 1.0
+    assert fast_object_mode(pd.Series(["a", "a", None])) == "a"
+    assert fast_object_mode(pd.Series([{"a": 1}, {"b": 1}, {"a": 1}])) == {"a": 1}
+    assert fast_object_mode(pd.Series([["a"], ["a"], None])) == ["a"]
+    assert pd.isna(fast_object_mode(pd.Series([["a"], None, None])))
+
+
 def test_comb():
     """Test n_choose_k and comb function"""
     assert n_choose_k(1, 1) == 1
